@@ -45,8 +45,7 @@ fn windows_interpreter_no_build(
     // those for 64-bit targets
     if pointer_width != target_width {
         println!(
-            "👽 {}.{} is installed as {}-bit, while the target is {}-bit. Skipping.",
-            major, minor, pointer_width, target_width
+            "👽 {major}.{minor} is installed as {pointer_width}-bit, while the target is {target_width}-bit. Skipping."
         );
         return true;
     }
@@ -142,7 +141,7 @@ fn find_all_windows(target: &Target, min_python_minor: usize) -> Result<Vec<Stri
                     }
 
                     let executable = capture.get(6).unwrap().as_str();
-                    let version = format!("-{}.{}-{}", major, minor, pointer_width);
+                    let version = format!("-{major}.{minor}-{pointer_width}");
                     let output = Command::new(executable)
                         .args(["-c", code])
                         .output()
@@ -150,8 +149,7 @@ fn find_all_windows(target: &Target, min_python_minor: usize) -> Result<Vec<Stri
                     let path = str::from_utf8(&output.stdout).unwrap().trim();
                     if !output.status.success() || path.trim().is_empty() {
                         eprintln!(
-                            "⚠️  Warning: couldn't determine the path to python for `py {}`",
-                            version
+                            "⚠️  Warning: couldn't determine the path to python for `py {version}`"
                         );
                         continue;
                     }
@@ -206,7 +204,7 @@ fn find_all_windows(target: &Target, min_python_minor: usize) -> Result<Vec<Stri
     // Fallback to pythonX.Y for Microsoft Store versions
     for minor in min_python_minor..=MAXIMUM_PYTHON_MINOR {
         if !versions_found.contains(&(3, minor)) {
-            let executable = format!("python3.{}.exe", minor);
+            let executable = format!("python3.{minor}.exe");
             if let Some(python_info) = windows_python_info(Path::new(&executable))? {
                 if windows_interpreter_no_build(
                     python_info.major,
@@ -311,7 +309,7 @@ impl FromStr for InterpreterKind {
         match s.to_ascii_lowercase().as_str() {
             "cpython" => Ok(InterpreterKind::CPython),
             "pypy" => Ok(InterpreterKind::PyPy),
-            unknown => Err(format!("Unknown interpreter kind '{}'", unknown)),
+            unknown => Err(format!("Unknown interpreter kind '{unknown}'")),
         }
     }
 }
@@ -571,7 +569,7 @@ impl PythonInterpreter {
                         );
                         return Ok(None);
                     } else {
-                        eprintln!("{}", stderr);
+                        eprintln!("{stderr}");
                         bail!(err_msg);
                     }
                 }
@@ -587,7 +585,7 @@ impl PythonInterpreter {
                             };
                             // Try py -x.y on Windows
                             let mut metadata_py = tempfile::NamedTempFile::new()?;
-                            write!(metadata_py, "{}", GET_INTERPRETER_METADATA)?;
+                            write!(metadata_py, "{GET_INTERPRETER_METADATA}")?;
                             let mut cmd = Command::new("cmd");
                             cmd.arg("/c")
                                 .arg("py")
@@ -736,7 +734,7 @@ impl PythonInterpreter {
             find_all_windows(target, min_python_minor)?
         } else {
             let mut executables: Vec<String> = (min_python_minor..=MAXIMUM_PYTHON_MINOR)
-                .map(|minor| format!("python3.{}", minor))
+                .map(|minor| format!("python3.{minor}"))
                 .collect();
             // Also try to find PyPy for cffi and pyo3 bindings
             if matches!(bridge, BridgeModel::Cffi)
@@ -744,7 +742,7 @@ impl PythonInterpreter {
                 || bridge.is_bindings("pyo3-ffi")
             {
                 executables.extend(
-                    (min_python_minor..=MAXIMUM_PYPY_MINOR).map(|minor| format!("pypy3.{}", minor)),
+                    (min_python_minor..=MAXIMUM_PYPY_MINOR).map(|minor| format!("pypy3.{minor}")),
                 );
             }
             executables
